@@ -10,15 +10,17 @@ use Data::Record::Serialize::Error { errors =>
         schema
         create
         insert
+        sqlite_backend
    )] }, -all;
 
-our $VERSION = '0.27'; # TRIAL
+our $VERSION = '0.33'; # TRIAL
 
 use Data::Record::Serialize::Types -types;
 
 use SQL::Translator;
 use SQL::Translator::Schema;
 use Types::Standard -types;
+use Types::Common::String qw( NonEmptySimpleStr );
 
 use List::Util qw[ pairmap ];
 
@@ -83,10 +85,10 @@ has table => (
 
 
 
+
 has schema => (
     is        => 'ro',
-    predicate => 1,
-    isa       => Str,
+    isa       => Maybe[NonEmptySimpleStr],
 );
 
 
@@ -156,10 +158,18 @@ has _sth => (
 );
 
 has _dbh => (
-    is       => 'rwp',
-    init_arg => undef,
+    is        => 'rwp',
+    init_arg  => undef,
+    clearer   => 1,
+    predicate => 1,
 );
 
+
+
+
+
+
+
 has column_defs => (
     is       => 'rwp',
     lazy     => 1,
@@ -264,8 +274,7 @@ sub _table_exists {
 
 sub _fq_table_name {
     my $self = shift;
-
-    join( '.', ( $self->has_schema ? ( $self->schema ) : () ), $self->table );
+    defined $self->schema ? $self->schema . '.' . $self->table : $self->table;
 }
 
 has _dsn_components => (
@@ -306,10 +315,11 @@ has _producer => (
 
 
 
+
 sub setup {
     my $self = shift;
 
-    return if $self->_dbh;
+    return if $self->_has_dbh;
 
     my %attr = (
         AutoCommit               => !$self->batch,
@@ -318,8 +328,21 @@ sub setup {
         'private_' . __PACKAGE__ => __FILE__ . __LINE__,
     );
 
-    $attr{sqlite_allow_multiple_statements} = 1
-      if $self->_dbi_driver eq 'SQLite';
+
+    if ( $self->_dbi_driver eq 'SQLite' ) {
+        my $DBD_SQLite_VERSION = 1.31;
+
+        error( 'sqlite_backend',
+            "need DBD::SQLite >= $DBD_SQLite_VERSION; have @{[ DBD::SQLite->VERSION ]}"
+          )
+          unless eval {
+            require DBD::SQLite;
+            DBD::SQLite->VERSION( $DBD_SQLite_VERSION );
+            1;
+          };
+
+        $attr{sqlite_allow_multiple_statements} = 1;
+    }
 
     my $connect = $self->_cached ? 'connect_cached' : 'connect';
 
@@ -359,7 +382,6 @@ sub setup {
         my $sql = $tr->translate
           or error( 'schema', $tr->error );
 
-        # print STDERR $sql;
         eval { $self->_dbh->do( $sql ); };
 
         error( 'create', { msg => "error in table creation: $@", payload => $sql } )
@@ -370,7 +392,7 @@ sub setup {
 
     my $sql = sprintf(
         "insert into %s (%s) values (%s)",
-        $self->_fq_table_name,
+        $self->_dbh->quote_identifier( undef, $self->schema, $self->table ),
         join( ',', @{ $self->output_fields } ),
         join( ',', ( '?' ) x @{ $self->output_fields } ),
     );
@@ -434,6 +456,8 @@ sub setup {
 sub flush {
     my $self = shift;
 
+    return 1 unless $self->_has_dbh;
+
     my $queue = $self->queue;
 
     if ( @{ $queue } ) {
@@ -525,11 +549,11 @@ after '_trigger_output_types' => sub {
 sub close {
     my $self = shift;
 
-    $self->flush
-      if $self->batch;
+    return 1 unless $self->_has_dbh;
 
-    $self->_dbh->disconnect
-      if defined $self->_dbh;
+    $self->flush if $self->batch;
+    $self->_dbh->disconnect;
+    $self->_clear_dbh;
 
     1;
 }
@@ -552,7 +576,8 @@ sub DEMOLISH {
         if @{ $self->queue };
 
     $self->_dbh->disconnect
-      if defined $self->_dbh;
+      if  $self->_has_dbh;
+
 }
 
 
@@ -592,7 +617,7 @@ Data::Record::Serialize::Encode::dbi - store a record in a database
 
 =head1 VERSION
 
-version 0.27
+version 0.33
 
 =head1 SYNOPSIS
 
@@ -798,6 +823,9 @@ C<Data::Record::Serialize::Encode::dbi::queue> warning to silence it.
 
 =for Pod::Coverage has_schema
 
+=for Pod::Coverage _has_dbh
+  _clear_dbh
+
 =for Pod::Coverage setup
 
 =for Pod::Coverage say
