@@ -2,11 +2,37 @@ package Data::Record::Serialize::Encode::json;
 
 # ABSTRACT: encoded a record as JSON
 
+use strict;
+use warnings;
+
+use Data::Record::Serialize::Error { errors => [ 'json_backend' ] }, -all;
+
 use Moo::Role;
 
-our $VERSION = '0.27'; # TRIAL
+our $VERSION = '0.33'; # TRIAL
 
-use JSON::MaybeXS qw[ encode_json ];
+
+BEGIN {
+    my $Cpanel_JSON_XS_VERSION = 3.0236;
+
+    # Module::Version doesn't load the code, so avoids loading
+    # Cpanel::JSON::XS's version of JSON::PP::Boolean which prevents
+    # loading the version provided by JSON::PP if Cpanel::JSON::XS is
+    # too old. Symbol::delete_package could be used to remove
+    # Cpanel::JSON::XS's version, but it's better not to load it in
+    # the first place.
+    require Module::Version;
+    if ( Module::Version::get_version( 'Cpanel::JSON::XS' ) >= $Cpanel_JSON_XS_VERSION ) {
+        require  Cpanel::JSON::XS;
+        *encode_json = \&Cpanel::JSON::XS::encode_json;
+    }
+    elsif ( eval { require JSON::PP } ) {
+        *encode_json = \&JSON::PP::encode_json;
+    }
+    else {
+        error( 'json_backend', "can't find either Cpanel::JSON::XS (>= $Cpanel_JSON_XS_VERSION) or JSON::PP. Please install one of them." );
+    }
+};
 
 use namespace::clean;
 
@@ -30,7 +56,7 @@ sub to_bool { $_[1] ? \1 : \0 }
 
 
 
-sub encode { shift; goto \&encode_json }
+sub encode { encode_json( $_[1] ) }
 
 with 'Data::Record::Serialize::Role::Encode';
 
@@ -58,7 +84,7 @@ Data::Record::Serialize::Encode::json - encoded a record as JSON
 
 =head1 VERSION
 
-version 0.27
+version 0.33
 
 =head1 SYNOPSIS
 
@@ -99,6 +125,7 @@ Convert a truthy value to something that the JSON encoders will recognize as a b
 
 =for Pod::Coverage numify
 stringify
+encode_json
 
 =head1 INTERFACE
 
